@@ -7,7 +7,7 @@ import io
 import logging
 from pypykatz.crypto.RC4 import RC4
 from pypykatz.alsadecryptor.package_commons import PackageDecryptor
-from pypykatz.commons.win_datatypes import LONG
+from pypykatz.alsadecryptor.win_datatypes import LONG
 
 class LsaDecryptor_NT5(PackageDecryptor):
 	def __init__(self, reader, decryptor_template, sysinfo):
